package nfa;

import java.io.File;
import java.io.IOException;
import java.util.Scanner;
import java.util.Vector;

/**
 * A simple scanner to help process NFA input files.
 * This class is modeled after {@link java.util.Scanner}.
 */
public class NFAScanner {
    
    /** Just use an underlying Scanner to do all the work */
    private Scanner in;
    
    /**
     * Create a new NFAScanner that reads input
     * from the terminal.
     */
    public NFAScanner() {
	in = new Scanner(System.in);
    }
    
    /**
     * Create a new NFAScanner that reads input from the File
     * provided as a parameter.
     */
    public NFAScanner(File f) throws IOException {
	in = new Scanner(f);
    }
    
    /**
     * Return true if the next token in the input stream can be
     * interpreted as in integer value.
     */
    public boolean hasNextInt() {
	return in.hasNextInt();
    }
    
    /**
     * Return the next token, after converting it to an integer.  This
     * method may throw an exception if the next token is not an integer.
     */
    public int nextInt() {
	return in.nextInt();
    }
    
    /**
     * Return true if there is more input left.
     */
    public boolean hasNext() {
	return in.hasNext();
    }
    
    /**
     * Return the next line of text.
     */
    public String nextLine() {
	return in.nextLine();
    }
    
    /**
     * Return true if the next token is an int list
     * of the form <tt>(1,2,3)</tt>.
     */
    public boolean hasNextIntList() {
	return in.hasNext("\\(((([0-9]+,)+[0-9]+)|[0-9]+)?\\)");
    }
    
    /**
     * Read an int list of the form <tt>(1,2,3)</tt> and return
     * it as a {@link java.util.Vector} of integers.
     */
    public Vector<Integer> nextIntList() {
	Vector<Integer> n = new Vector<Integer>();
	String list = in.next("\\(((([0-9]+,)+[0-9]+)|[0-9]+)?\\)");
	list = list.substring(1, list.length() - 1);
	if (list.length() > 0) { 
	    String ns[] = list.split(",");
	    for (String s : ns) {
		n.add(new Integer(s));
	    }
	} 
	return n;
    }
}
